# utility-helper

This is the README file for the project.

this package include some modules which simply wrapper python known packages or modules,
such as wx, logging and also include utils helping do some other things.

- 0.1.10:
        2021.01.28:
        1. 修复一些python3运行时语法兼容错误

- 0.1.9:
        2020.02.21:
        1.修复一些python2和3语法兼容错误
        2.增加部分wxpython4控件包装类

- 0.1.8:
        1.修复SerialReaderObserver参数名错误
        2.Synchronization模块，删除apply函数，兼容python2和3

- 0.1.6:
        2019.07.16:
        1.增加对pyserial库的封装

-  0.1.3:
        2018.10.09:
        1.remove wxpython helper
        2.support python3

- 0.1.2:
        2017.08.02:
        1.add decorator 'singletion' for generation of python class'ssingleton pattern.

